@@ -1,7 +1,7 @@
 package Wubot::Plugin::RSS;
 use Moose;
 
-our $VERSION = '0.1_5'; # VERSION
+our $VERSION = '0.1_6'; # VERSION
 
 use XML::Feed;
 
@@ -103,6 +103,76 @@ sub check {
     return { cache => $cache, react => \@react };
 }
 
-
-
 1;
+
+
+__END__
+
+
+=head1 NAME
+
+Wubot::Plugin::RSS - monitor an RSS feed
+
+
+=head1 VERSION
+
+version 0.1_6
+
+=head1 SYNOPSIS
+
+  ~/wubot/config/plugins/RSS/slashdot.yaml
+
+  ---
+  tags: news
+  url: http://rss.slashdot.org/Slashdot/slashdot
+  delay: 30m
+
+  ~/wubot/config/plugins/RSS/my-feed-name.yaml
+
+  ---
+  url: http://www.xyz.com/rss
+  delay: 1h
+  user: dude
+  pass: lebowski
+  proxy: socks://localhost:2080
+
+
+=head1 DESCRIPTION
+
+Monitors an RSS/Atom feed (anything that can be parsed with
+XML::Feed).  Sends a message any time a new article shows up in the
+feed.  The message will contain the following fields:
+
+  title: the article title
+  subject: the article title, used for notifications
+  link: the link
+  body: article body
+
+=head1 ERRORS
+
+If an error occurs requesting the data, a reactor message will be sent
+containing the error in the subject, e.g.:
+
+  subject: Request failure: 404 Not Found
+
+
+If the RSS feed cannot be parsed by XML::Feed, a message will be sent
+containing the XML::Feed->errstr, e.g.:
+
+  subject: Failure parsing XML Feed: $error text
+
+If the feed contains no articles, the message will contain the text:
+
+  subject: RSS-myfeed: No items in feed
+
+=head1 CACHE
+
+THe RSS monitor uses the global cache mechanism, so each time the
+check runs, it will update a file such as:
+
+  ~/wubot/cache/RSS-myfeed.yaml
+
+The monitor caches all subject in the feed.  When a new (previously
+unseen) subject shows up on the feed, the message will be sent, and
+the cache will be updated.  Removing the cache file will cause all
+items in the feed to be sent again.
